@@ -1,5 +1,6 @@
    require("ts")
    require("dse2")
+   require("padi")
    require("dsepadi")
    require("monitor")
 #   A TS PADI server is necessary for these tests.
@@ -16,25 +17,11 @@
  cat("search path ", search(),"\n")
  cat("PATH set to ",  Sys.getenv("PATH"), "\n")
  cat("PADI set to ",  Sys.getenv("PADI"), "\n")
+ cat("PADI_LDLIB set to ",  Sys.getenv("PADI_LDLIB"), "\n")
  cat("PADI_STARTUP set to ", Sys.getenv("PADI_STARTUP"), "\n")
  cat("PADI_CLEANUP set to ", Sys.getenv("PADI_CLEANUP"), "\n")
  cat("user name set to ", Sys.info()[["user"]], "\n")
 
-   if (is.S()) {
-	# the next 2 lines remove old versions of PADI in the search path
- 	invisible(if(0!=length(grep("b*/PADI/.Data",search())))
-                         detach(grep("b*/PADI/.Data",search()))  )
-	attach(paste(Sys.getenv("PADI"),"/.Data", sep=""), pos=2)
-	#load.padi(from=".")    # this gets the version in pwd
-	load.padi()           # this gets the version indicated by PADI
-	# load.padi does the following two dynamic loads 
-	#dyn.load.shared("/usr/lib/libnsl.so")     # splus 3.3 on SunOS5
-	# If the shared library is not loaded then the next has missing symbols
-	#dyn.load(paste(Sys.getenv("PADI"),"/lib/splusclnt.o", sep=""))
-	search()
-   }
-
-
 
 ###########################################################################
 
